@@ -56,7 +56,8 @@ typedef enum {
 	PANEL_OBJECT_APPLET,
 	PANEL_OBJECT_ACTION,
 	PANEL_OBJECT_MENU_BAR,
-	PANEL_OBJECT_SEPARATOR
+	PANEL_OBJECT_SEPARATOR,
+	PANEL_OBJECT_USER_MENU
 } PanelObjectType;
 
 typedef enum {
