@@ -57,6 +57,7 @@
 #include "panel-globals.h"
 #include "panel-icon-names.h"
 #include "panel-lockdown.h"
+#include "panel-menu-bar-object.h"
 #include "panel-recent.h"
 #include "panel-stock-icons.h"
 #include "panel-util.h"
@@ -99,6 +100,7 @@ struct _PanelPlaceMenuItemPrivate {
 struct _PanelDesktopMenuItemPrivate {
 	GtkWidget   *menu;
 	PanelWidget *panel;
+	GtkIconSize  icon_size;
 
 #ifdef HAVE_TELEPATHY_GLIB
 	GList            *presence_items;
@@ -1614,23 +1616,38 @@ panel_desktop_menu_item_class_init (PanelDesktopMenuItemClass *klass)
 }
 
 GtkWidget *
-panel_place_menu_item_new (gboolean use_image)
+panel_place_menu_item_new (gboolean use_image,
+			   gboolean in_menubar)
 {
 	PanelPlaceMenuItem *menuitem;
-	GtkWidget          *image;
+	const char          *name;
+	const char          *icon_name;
 
 	menuitem = g_object_new (PANEL_TYPE_PLACE_MENU_ITEM, NULL);
 
-	if (use_image)
-		image = gtk_image_new_from_icon_name (PANEL_ICON_FOLDER,
-						      panel_menu_icon_get_size ());
-	else
-		image = NULL;
+	name = _("Places");
+	icon_name = PANEL_ICON_FOLDER;
 
-	setup_menuitem (GTK_WIDGET (menuitem),
-			image ? panel_menu_icon_get_size () : GTK_ICON_SIZE_INVALID,
-			image,
-			_("Places"));
+	if (in_menubar) {
+		gtk_menu_item_set_label (GTK_MENU_ITEM (menuitem), name);
+		if (use_image) {
+			GtkWidget *image;
+			image = gtk_image_new_from_icon_name (icon_name,
+							      panel_menu_bar_object_icon_get_size ());
+			gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem),
+						       image);
+		}
+	} else {
+		if (use_image)
+			setup_menu_item_with_icon (GTK_WIDGET (menuitem),
+						   panel_menu_icon_get_size (),
+						   icon_name, NULL, NULL,
+						   name);
+		else
+			setup_menuitem (GTK_WIDGET (menuitem),
+					GTK_ICON_SIZE_INVALID, NULL,
+					name);
+	}
 
 	menuitem->priv->menu = panel_place_menu_item_create_menu (menuitem);
 	gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuitem),
@@ -1670,7 +1687,7 @@ panel_desktop_menu_item_on_presence_changed (PanelSessionManager             *ma
 	 * menu */
 	if (image) {
 		gtk_image_set_from_icon_name (GTK_IMAGE (image),
-					      icon, panel_menu_icon_get_size ());
+					      icon, desktop_item->priv->icon_size);
 	}
 
 	for (l = desktop_item->priv->presence_items; l != NULL; l = l->next) {
@@ -1693,10 +1710,12 @@ panel_desktop_menu_item_on_presence_changed (PanelSessionManager             *ma
 
 GtkWidget *
 panel_desktop_menu_item_new (gboolean use_image,
+			     gboolean in_menubar,
 			     gboolean append_lock_logout)
 {
 	PanelDesktopMenuItem *menuitem;
 	char                 *name;
+	const char           *icon_name;
 #ifdef HAVE_TELEPATHY_GLIB
 	PanelSessionManager  *manager;
 #endif
@@ -1704,27 +1723,44 @@ panel_desktop_menu_item_new (gboolean use_image,
 	menuitem = g_object_new (PANEL_TYPE_DESKTOP_MENU_ITEM, NULL);
 
 	name = panel_util_get_user_name ();
-
-	if (use_image) {
 #ifdef HAVE_TELEPATHY_GLIB
-		setup_menu_item_with_icon (GTK_WIDGET (menuitem),
-					   panel_menu_icon_get_size (),
-					   PANEL_ICON_USER_AVAILABLE,
-					   NULL, NULL,
-					   name);
+	icon_name = PANEL_ICON_USER_AVAILABLE;
+#else
+	icon_name = PANEL_ICON_COMPUTER;
+#endif
+
+	/* if we're in a menubar, we don't want to use setup_* as it changes
+	 * the size requests and can make the panels bigger than we'd like */
+	if (in_menubar) {
+		gtk_menu_item_set_label (GTK_MENU_ITEM (menuitem), name);
+		menuitem->priv->icon_size = panel_menu_bar_object_icon_get_size ();
+
+		if (use_image) {
+			GtkWidget *image;
+			image = gtk_image_new_from_icon_name (icon_name,
+							      menuitem->priv->icon_size);
+			gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menuitem),
+						       image);
+		}
+	} else {
+		menuitem->priv->icon_size = panel_menu_icon_get_size ();
+
+		if (use_image)
+			setup_menu_item_with_icon (GTK_WIDGET (menuitem),
+						   menuitem->priv->icon_size,
+						   icon_name, NULL, NULL,
+						   name);
+		else
+			setup_menuitem (GTK_WIDGET (menuitem),
+					GTK_ICON_SIZE_INVALID, NULL,
+					name);
+	}
+
+#ifdef HAVE_TELEPATHY_GLIB
+	if (use_image)
 		gtk_image_menu_item_set_always_show_image (GTK_IMAGE_MENU_ITEM (menuitem),
 							   TRUE);
-#else
-		setup_menu_item_with_icon (GTK_WIDGET (menuitem),
-					   panel_menu_icon_get_size (),
-					   PANEL_ICON_COMPUTER,
-					   NULL, NULL,
-					   name);
 #endif
-	} else
-		setup_menuitem (GTK_WIDGET (menuitem),
-				GTK_ICON_SIZE_INVALID, NULL,
-				name);
 
 	g_free (name);
 
